==> necroplayer2_0.1.1.tar.gz: necroplayer2-0.1.1/translations/necroplayer2_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>CoverDialog</name>
    <message>
        <location filename="../src/CoverDialog.cpp" line="14"/>
        <source>Album art</source>
        <translation>Album-Cover</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="37"/>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="38"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="39"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="9"/>
        <source>no artist info</source>
        <translation>Interpret: keine Info</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="10"/>
        <source>no album info</source>
        <translation>Album: keine Info</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Config.cpp" line="23"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="41"/>
        <source>Player</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="53"/>
        <source>Volume slider</source>
        <translation>Lautstärkeregler</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="58"/>
        <source>System volume</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="61"/>
        <source>Player volume</source>
        <translation>Anwendung</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="75"/>
        <source>Playlist view</source>
        <translation>Ansicht der Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="79"/>
        <source>Separators</source>
        <translation>Trennstriche</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="82"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Playlist items</source>
        <translation>Einträge der Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="100"/>
        <source>Metadata</source>
        <translation>Metadaten</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="103"/>
        <source>Filenames</source>
        <translation>Dateinamen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="117"/>
        <source>Retrieve metadata</source>
        <translation>Metadaten abrufen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="121"/>
        <source>Playlist</source>
        <translation>Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="124"/>
        <source>Played song</source>
        <translation>Gespieltes Lied</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="10"/>
        <source>Save playing position on quit</source>
        <translation>Abspielposition beim Beenden speichern</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="190"/>
        <source>Media</source>
        <translation>Medien</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="195"/>
        <source>Directories</source>
        <translation>Verzeichnisse</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="16"/>
        <source>Directory</source>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="11"/>
        <source>Save playing position on quit (second line if needed)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="12"/>
        <source>Pause on headphones disconnect</source>
        <translation>Pause beim Abziehen des Kopfhörers</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="13"/>
        <source>Pause on headphones disconnect (second line if needed)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="14"/>
        <source>Resume on headphones connect</source>
        <translation>Fortfahren beim Einstecken des</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="15"/>
        <source>Resume on headphones connect (second line if needed)</source>
        <translation>Kopfhörers</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="173"/>
        <source>Phone button function</source>
        <translation>Kopfhörer-Tastenfunktion</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="18"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <source>No.</source>
        <translation>Nr.</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="20"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="21"/>
        <source>Browse</source>
        <translation>Durchsuchen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="23"/>
        <source>Show descriptions in path display</source>
        <translation>Beschreibungen in der Pfadansicht</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="24"/>
        <source>Show descriptions in path display (second line if needed)</source>
        <translation>anzeigen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="25"/>
        <source>Hide description of first directory</source>
        <translation>Beschreibung des ersten Verzeichnisses</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="26"/>
        <source>Hide description of first directory (second line if needed)</source>
        <translation>nicht anzeigen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="176"/>
        <source>Play / Pause</source>
        <translation>Abspielen / Pause</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="177"/>
        <source>Stop playback</source>
        <translation>Wiedergabe stoppen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="178"/>
        <source>Next song</source>
        <translation>Nächstes Lied</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="179"/>
        <source>Previous song</source>
        <translation>Vorheriges Lied</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="180"/>
        <source>Do nothing</source>
        <translation>Nichts machen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="252"/>
        <source>Show hidden files</source>
        <translation>Verborgene Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="258"/>
        <source>requires restart</source>
        <translation>benötigt Neustart</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="22"/>
        <location filename="../src/SettingsDialog.cpp" line="266"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="17"/>
        <source>New Directory</source>
        <translation>Neues Verzeichnis</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="273"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>SimpleViewFM</name>
    <message>
        <location filename="../src/SimpleViewFM.cpp" line="20"/>
        <source>FM transmission frequency (MHz)</source>
        <translation>UKW-Sendefrequenz (MHz)</translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="113"/>
        <source>Playing</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="114"/>
        <source>Media</source>
        <translation>Medien</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="150"/>
        <source>further developed by</source>
        <translation>weiterentwickelt von</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="152"/>
        <source>Playlist files</source>
        <translation>Wiedergabelisten</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="382"/>
        <source>Open Playlist</source>
        <translation>Wiedergabeliste laden</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="385"/>
        <source>Save Playlist</source>
        <translation>Wiedergabeliste speichern</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="388"/>
        <source>Open Url</source>
        <translation>Url öffnen</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="391"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="394"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="151"/>
        <source>based on and inspired by</source>
        <translation>basierend auf und angeregt durch</translation>
    </message>
</context>
<context>
    <name>UILibrary</name>
    <message>
        <location filename="../src/UILibrary.cpp" line="10"/>
        <source>Select view</source>
        <translation>Ansicht wählen</translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="10"/>
        <source>Clear playlist</source>
        <translation>Wiedergabeliste leeren</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/UrlDialog.cpp" line="13"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="18"/>
        <source>Url</source>
        <translation>Url</translation>
    </message>
</context>
</TS>

==> necroplayer2_0.2.2.tar.gz: necroplayer2-0.2.2/translations/necroplayer2_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>CoverDialog</name>
    <message>
        <location filename="../src/CoverDialog.cpp" line="14"/>
        <source>Album art</source>
        <translation>Album-Cover</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="37"/>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="38"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="39"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="9"/>
        <source>no artist info</source>
        <translation>Interpret: keine Info</translation>
    </message>
    <message>
        <location filename="../src/CoverDialog.cpp" line="10"/>
        <source>no album info</source>
        <translation>Album: keine Info</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Config.cpp" line="23"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="41"/>
        <source>Player</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="53"/>
        <source>Volume slider</source>
        <translation>Lautstärkeregler</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="58"/>
        <source>System volume</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="61"/>
        <source>Player volume</source>
        <translation>Anwendung</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="75"/>
        <source>Playlist view</source>
        <translation>Ansicht der Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="79"/>
        <source>Separators</source>
        <translation>Trennstriche</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="82"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Playlist items</source>
        <translation>Einträge der Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="100"/>
        <source>Metadata</source>
        <translation>Metadaten</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="103"/>
        <source>Filenames</source>
        <translation>Dateinamen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="117"/>
        <source>Retrieve metadata</source>
        <translation>Metadaten abrufen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="121"/>
        <source>Playlist</source>
        <translation>Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="124"/>
        <source>Played song</source>
        <translation>Gespieltes Lied</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="10"/>
        <source>Save playing position on quit</source>
        <translation>Abspielposition beim Beenden speichern</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="190"/>
        <source>Media</source>
        <translation>Medien</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="195"/>
        <source>Directories</source>
        <translation>Verzeichnisse</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="16"/>
        <source>Directory</source>
        <translation>Verzeichnis</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="11"/>
        <source>Save playing position on quit (second line if needed)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="12"/>
        <source>Pause on headphones disconnect</source>
        <translation>Pause beim Abziehen des Kopfhörers</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="13"/>
        <source>Pause on headphones disconnect (second line if needed)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="14"/>
        <source>Resume on headphones connect</source>
        <translation>Fortfahren beim Einstecken des</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="15"/>
        <source>Resume on headphones connect (second line if needed)</source>
        <translation>Kopfhörers</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="173"/>
        <source>Phone button function</source>
        <translation>Kopfhörer-Tastenfunktion</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="18"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <source>No.</source>
        <translation>Nr.</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="20"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="21"/>
        <source>Browse</source>
        <translation>Durchsuchen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="23"/>
        <source>Show descriptions in path display</source>
        <translation>Beschreibungen in der Pfadansicht</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="24"/>
        <source>Show descriptions in path display (second line if needed)</source>
        <translation>anzeigen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="25"/>
        <source>Hide description of first directory</source>
        <translation>Beschreibung des ersten Verzeichnisses</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="26"/>
        <source>Hide description of first directory (second line if needed)</source>
        <translation>nicht anzeigen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="176"/>
        <source>Play / Pause</source>
        <translation>Abspielen / Pause</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="177"/>
        <source>Stop playback</source>
        <translation>Wiedergabe stoppen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="178"/>
        <source>Next song</source>
        <translation>Nächstes Lied</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="179"/>
        <source>Previous song</source>
        <translation>Vorheriges Lied</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="180"/>
        <source>Do nothing</source>
        <translation>Nichts machen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="252"/>
        <source>Show hidden files</source>
        <translation>Verborgene Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="258"/>
        <source>requires restart</source>
        <translation>benötigt Neustart</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="22"/>
        <location filename="../src/SettingsDialog.cpp" line="266"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="17"/>
        <source>New Directory</source>
        <translation>Neues Verzeichnis</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="273"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>SimpleViewFM</name>
    <message>
        <location filename="../src/SimpleViewFM.cpp" line="22"/>
        <source>FM transmission frequency (MHz)</source>
        <translation>UKW-Sendefrequenz (MHz)</translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="113"/>
        <source>Playing</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="114"/>
        <source>Media</source>
        <translation>Medien</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="150"/>
        <source>further developed by</source>
        <translation>weiterentwickelt von</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="151"/>
        <source>based on</source>
        <translation>basierend auf</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="152"/>
        <source>Playlist files</source>
        <translation>Wiedergabelisten</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="382"/>
        <source>Open Playlist</source>
        <translation>Wiedergabeliste laden</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="385"/>
        <source>Save Playlist</source>
        <translation>Wiedergabeliste speichern</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="388"/>
        <source>Open Url</source>
        <translation>Url öffnen</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="391"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="394"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>UILibrary</name>
    <message>
        <location filename="../src/UILibrary.cpp" line="11"/>
        <source>Select view</source>
        <translation>Ansicht wählen</translation>
    </message>
    <message>
        <location filename="../src/UILibrary.cpp" line="12"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../src/UILibrary.cpp" line="13"/>
        <source>Confirm deletion</source>
        <translation>Löschen bestätigen</translation>
    </message>
    <message>
        <location filename="../src/UILibrary.cpp" line="33"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <location filename="../src/UIPlaylist.cpp" line="10"/>
        <source>Clear playlist</source>
        <translation>Wiedergabeliste leeren</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/UrlDialog.cpp" line="13"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../src/UrlDialog.cpp" line="18"/>
        <source>Url</source>
        <translation>Url</translation>
    </message>
</context>
</TS>
